@@ -709,23 +709,20 @@ def get_project_id(base_url, project_name, token):
     url = base_url + '/api/ssh_v2/hook/fetch/?project_name={}'.format(project_name)
     headers = {"Content-Type": "application/json",
                 "token": token}
-
     session = Session()
     session.mount('http://', HTTPAdapter(max_retries=3))
     session.mount('https://', HTTPAdapter(max_retries=3))
 
     resp = session.get(url=url, headers=headers, verify=False, allow_redirects=True)
-
     if resp.status_code == 200:
         return resp.json()
-
     if resp.status_code == 401:
         logging.debug('Could not verify your token, please check it and try again.')
         # sys.exit(1)
         raise Exception('Could not verify your token, please check it and try again.')
 
     if resp.status_code != 200:
-        logging.debug('Can\'t not get a connection to the server, please check your url or token and try again.')
+        logging.debug('Can\'t not get a connection to the server, please check your url or token and try again. Http status {}'.format(resp.status_code))
         # sys.exit(1)
         raise Exception('Can\'t not get a connection to the server, please check your url or token and try again.')
 
@@ -1171,7 +1168,6 @@ parser.add_argument('--auto_repo_name', action='store_true', default=False,
                     help='Use Git remote as repository name.')
 
 args = parser.parse_args()
-
 base_url = args.url.rstrip('/')
 project = args.project
 token = args.token
@@ -1180,22 +1176,26 @@ number = args.number if args.number else 100
 branch = args.branch
 blame = args.blame
 debug = args.debug
+if debug:
+    logging.info('Setting debug')
+    logging.getLogger().setLevel(logging.DEBUG)
+    for handler in logging.getLogger().handlers:
+        handler.setLevel(logging.DEBUG)
 debug = True
 
 repo_name = args.repo_name
 auto_repo_name = args.auto_repo_name
-
 if auto_repo_name:
     REPOSITORY_NAME = get_repo_name()
 else:
     REPOSITORY_NAME = repo_name
-
+logging.debug('Finding project id')
 
 try:
     project_id_data = get_project_id(base_url=base_url, project_name=project, token=token)
 except Exception as exc:
     sys.exit(1)
-
+logging.debug('Project id set')
 
 if 'project_id' in project_id_data:
     project_id = project_id_data['project_id']
