@@ -2,4 +2,9 @@ azurefilter = "TestCategory=BDDWebSPV&TestCategory=$(TestCategory)&TestCategory=
 
 if azurefilter[0:-1].endswith("TestCategory=Batch"):
     azurefilter = azurefilter[0:-19]
-print(azurefilter)
\ No newline at end of file
+print(azurefilter)
+
+testName = "asdftxt"
+if "." not in testName:
+    testName = ""
+print(testName)
\ No newline at end of file
